@@ -151,8 +151,8 @@ def get_user_uid(token: AnyStr=None) ->str:
 
     if token is None:
         token = request.headers.get('Authorization', '').split(' ').pop()
-        if not token:
-            raise ValueError(f"Failed to retrieve token from http header from token {request.headers.get('Authorization', '')}")
+        if token == "":
+            return "No uid provided"
     claims = firebase_auth.verify_id_token(token)
 
     return claims['uid']
